Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddEquipo ¶
AddEquipo insert a new Equipo into database and returns last inserted Id on success.
func DeleteEquipo ¶
DeleteEquipo deletes Equipo by Id and returns error if the record to be deleted doesn't exist
func GetAllEquipo ¶
func GetAllEquipo(query map[string]string, fields []string, sortby []string, order []string, offset int64, limit int64) (ml []interface{}, err error)
GetAllEquipo retrieves all Equipo matches certain condition. Returns empty list if no records exist
func UpdateEquipoById ¶
UpdateEquipo updates Equipo by Id and returns error if the record to be updated doesn't exist
Types ¶
Click to show internal directories.
Click to hide internal directories.